pub enum CollapseScope {
StreamsTree,
StreamsTreeFiltered {
session_id: Id,
},
BlueprintStreamsTree,
BlueprintStreamsTreeFiltered {
session_id: Id,
},
BlueprintTree,
BlueprintTreeFiltered {
session_id: Id,
},
}Expand description
The various scopes for which we want to track collapsed state.
Variants
StreamsTree
Stream tree from the time panel
StreamsTreeFiltered
Stream tree from the time panel, when the filter is active
BlueprintStreamsTree
The stream tree from the blueprint debug time panel
BlueprintStreamsTreeFiltered
The stream tree from the blueprint debug time panel, when the filter is active
BlueprintTree
Blueprint tree from the blueprint panel (left panel)
BlueprintTreeFiltered
Blueprint tree from the blueprint panel (left panel), when the filter is active
Implementations
Sourceimpl CollapseScope
impl CollapseScope
Sourcepub fn item(self, item: Item) -> Option<CollapsedId>
pub fn item(self, item: Item) -> Option<CollapsedId>
Create a CollapsedId for an Item of supported kind.
Sourcepub fn container(self, container_id: ContainerId) -> CollapsedId
pub fn container(self, container_id: ContainerId) -> CollapsedId
Create a CollapsedId for a container in this scope.
Sourcepub fn view(self, view_id: ViewId) -> CollapsedId
pub fn view(self, view_id: ViewId) -> CollapsedId
Create a CollapsedId for a view in this scope.
Sourcepub fn contents(self, contents: Contents) -> CollapsedId
pub fn contents(self, contents: Contents) -> CollapsedId
Create a CollapsedId for a Contents in this scope.
Sourcepub fn data_result(
self,
view_id: ViewId,
entity_path: EntityPath,
) -> CollapsedId
pub fn data_result( self, view_id: ViewId, entity_path: EntityPath, ) -> CollapsedId
Create a CollapsedId for a data result in this scope.
Sourcepub fn entity(self, entity_path: EntityPath) -> CollapsedId
pub fn entity(self, entity_path: EntityPath) -> CollapsedId
Create a CollapsedId for an entity in this scope.