pub struct BufferAndFormatMatch {
pub buffer_target: ComponentIdentifier,
pub format_target: ComponentIdentifier,
pub buffer_matches: IntMap<ComponentIdentifier, DatatypeMatch>,
pub format_matches: IntSet<ComponentIdentifier>,
}Expand description
crate::VisualizabilityConstraints::BufferAndFormat matched for this entity.
Both a buffer component (matched by arrow datatype) and a format component (matched by arrow datatype AND semantic type) were found on the entity.
Fields
buffer_target: ComponentIdentifierThe buffer slot on the visualizer that needs to be mapped.
format_target: ComponentIdentifierThe format slot on the visualizer that needs to be mapped.
buffer_matches: IntMap<ComponentIdentifier, DatatypeMatch>All entity components whose arrow datatype matched the buffer’s expected type.
Guaranteed to have at least one entry.
format_matches: IntSet<ComponentIdentifier>The entity components that matched the format (by arrow datatype AND semantic type).
Guaranteed to have at least one entry.