pub struct EditRedapServerModalCommand {
pub origin: Origin,
pub open_on_success: Option<String>,
pub title: Option<String>,
}Expand description
Command to open the edit redap server modal.
This exists as a separate struct to make it convenient to funnel it through the redap browser command system.
Fields
origin: OriginWhich server should be edited?
open_on_success: Option<String>Provide a custom url to open when the server was successfully edited.
By default, the server dataset table is opened.
title: Option<String>Optional custom title for the modal.
Implementations