pub struct VideoAssetCache(/* private fields */);Expand description
Caches videos assets and their players based on media type & row id.
Implementations
Sourceimpl VideoAssetCache
impl VideoAssetCache
Sourcepub fn entry(
&mut self,
debug_name: String,
blob_row_id: RowId,
blob_component: ComponentIdentifier,
video_buffer: &Blob,
media_type: Option<&MediaType>,
decode_settings: DecodeSettings,
) -> Arc<Result<Video, VideoLoadError>> ⓘ
pub fn entry( &mut self, debug_name: String, blob_row_id: RowId, blob_component: ComponentIdentifier, video_buffer: &Blob, media_type: Option<&MediaType>, decode_settings: DecodeSettings, ) -> Arc<Result<Video, VideoLoadError>> ⓘ
Read in some video data and cache the result.
You may use the RowId as cache key if any.
NOTE: videos are never batched atm (they are mono-archetypes),
so we don’t need the instance id here.