pub struct VideoStreamCache(/* private fields */);Expand description
Caches metadata and active players for video streams.
It also keeps track of any additions and removals of video chunks.
Implementations
Sourceimpl VideoStreamCache
impl VideoStreamCache
Sourcepub fn entry(
&mut self,
store: &EntityDb,
entity_path: &EntityPath,
timeline: TimelineName,
decode_settings: DecodeSettings,
) -> Result<SharablePlayableVideoStream, VideoStreamProcessingError>
pub fn entry( &mut self, store: &EntityDb, entity_path: &EntityPath, timeline: TimelineName, decode_settings: DecodeSettings, ) -> Result<SharablePlayableVideoStream, VideoStreamProcessingError>
Looks up a video stream + players.
The first time a video stream that is looked up that isn’t in the cache, it creates all the necessary metadata. For any stream in the cache, metadata will be kept automatically up to date for incoming and removed video frames chunks.