pub struct ApplicationSelectionState { /* private fields */ }Expand description
Selection and hover state.
Both hover and selection are double buffered: Changes from one frame are only visible in the next frame.
Implementations
Sourceimpl ApplicationSelectionState
impl ApplicationSelectionState
Sourcepub fn on_frame_start(
&mut self,
item_retain_condition: impl Fn(&Item) -> bool,
fallback_selection: Option<Item>,
) -> SelectionChange<'_>
pub fn on_frame_start( &mut self, item_retain_condition: impl Fn(&Item) -> bool, fallback_selection: Option<Item>, ) -> SelectionChange<'_>
Called at the start of each frame.
pub fn on_frame_end(&mut self)
Sourcepub fn set_selection(&mut self, items: impl Into<SetSelection>)
pub fn set_selection(&mut self, items: impl Into<SetSelection>)
Sets several objects to be selected, updating history as needed.
Clears the selected item context if none was specified.
Sourcepub fn selected_items(&self) -> &ItemCollection
pub fn selected_items(&self) -> &ItemCollection
Returns the current selection.
Sourcepub fn hovered_items(&self) -> &ItemCollection
pub fn hovered_items(&self) -> &ItemCollection
Returns the currently hovered objects.
Sourcepub fn set_hovered(&self, hovered: impl Into<ItemCollection>)
pub fn set_hovered(&self, hovered: impl Into<ItemCollection>)
Set the hovered objects. Will be in Self::hovered_items on the next frame.
pub fn selection_item_contexts(&self) -> impl Iterator<Item = &ItemContext>
pub fn hovered_item_context(&self) -> Option<&ItemContext>
Sourcepub fn selection_changed(&self) -> Option<SelectionSource>
pub fn selection_changed(&self) -> Option<SelectionSource>
Returns Some if the selection changed this frame.
pub fn highlight_for_ui_element(&self, test: &Item) -> HoverHighlight