pub struct VisualizerExecutionOutput {
pub draw_data: Vec<QueueableDrawData>,
pub reports_per_instruction: Mutex<BTreeMap<VisualizerInstructionId, Vec1<VisualizerInstructionReport>>>,
/* private fields */
}Expand description
Result of running VisualizerSystem::execute.
Fields
draw_data: Vec<QueueableDrawData>Draw data produced by the visualizer.
It’s the view’s responsibility to queue this data for rendering.
reports_per_instruction: Mutex<BTreeMap<VisualizerInstructionId, Vec1<VisualizerInstructionReport>>>Reports (errors and warnings) encountered during execution, mapped to the visualizer instructions that caused them.
Reports from last frame will be shown in the UI for the respective visualizer instruction.
For errors that prevent any visualization at all, return a
ViewSystemExecutionError instead.
It’s mutex protected to make it easier to append errors while processing instructions in parallel.
Implementations
Sourceimpl VisualizerExecutionOutput
impl VisualizerExecutionOutput
Sourcepub fn set_missing_chunks(&self)
pub fn set_missing_chunks(&self)
Indicate that the view should show a loading indicator because data is missing.
Sourcepub fn any_missing_chunks(&self) -> bool
pub fn any_missing_chunks(&self) -> bool
Were any required chunks missing?
Sourcepub fn missing_chunk_reporter(&self) -> &MissingChunkReporter
pub fn missing_chunk_reporter(&self) -> &MissingChunkReporter
Can be used to report missing chunks.
Sourcepub fn report_error_for(
&self,
instruction_id: VisualizerInstructionId,
error: impl Into<String>,
)
pub fn report_error_for( &self, instruction_id: VisualizerInstructionId, error: impl Into<String>, )
Marks the given visualizer instruction as having encountered an error during visualization.
Sourcepub fn report_warning_for(
&self,
instruction_id: VisualizerInstructionId,
warning: impl Into<String>,
)
pub fn report_warning_for( &self, instruction_id: VisualizerInstructionId, warning: impl Into<String>, )
Marks the given visualizer instruction as having encountered a warning during visualization.
Sourcepub fn report(
&self,
instruction_id: VisualizerInstructionId,
report: VisualizerInstructionReport,
)
pub fn report( &self, instruction_id: VisualizerInstructionId, report: VisualizerInstructionReport, )
Report a detailed diagnostic for a visualizer instruction.
pub fn with_draw_data( self, draw_data: impl IntoIterator<Item = QueueableDrawData>, ) -> Self